@@ -72,7 +72,7 @@ def plot_inel_pred(
         Name of specimen.
     """
     rc('font', **{'family': 'sans-serif', 'sans-serif': ['Helvetica'], 'size': 10})
-    rc('text', usetex=True)
+    rc('text', usetex=False)
 
     dE1 = image.dE1[1, int(image.clustered[pixy, pixx])]
     dE2 = dE1 * 3
@@ -143,7 +143,7 @@ def plot_zlp_signal(image):
 
     """
     rc('font', **{'family': 'sans-serif', 'sans-serif': ['Helvetica'], 'size': 10})
-    rc('text', usetex=True)
+    rc('text', usetex=False)
 
     dE1 = image.dE1[1, :]
     dE2 = 3 + dE1 # TODO: make more general
@@ -186,7 +186,7 @@ def plot_zlp_signal(image):
         ax.text(0.03, 0.30, r'$\rm{\log N_{\mathrm{tot}}=%.2f}$'%(scaled_int), horizontalalignment='left', verticalalignment = 'center', transform = ax.transAxes)
         title = r'$\rm{\;Cluster\;%d}$' % (cluster_idx)
         ax.set_title(title)
-        ax.axes.yaxis.set_ticklabels([]) #TODO: seems to have no effect
+        ax.axes.yaxis.set_ticklabels([])
 
         ax.set_ylim(1, 1e3)
         ax.set_xlim(0, dE2[cluster_idx] + 1)
